import logging
import os
from logging.handlers import RotatingFileHandler

import config


def setup():
    log_dir = config.LOGGING_DIR or 'logs'
    # current_path == 'utils'
    current_path = os.path.dirname(os.path.abspath(__file__))
    # abs logger path
    logging_dir = os.path.join(os.path.dirname(current_path), log_dir)
    os.makedirs(logging_dir, exist_ok=True)

    # setup handlers
    handlers = [
        RotatingFileHandler(
            filename=os.path.join(logging_dir, 'clustersbot.log'),
            maxBytes=10 * 1024 * 1024,
            backupCount=9,
            encoding='utf8',
        )
    ]
    if config.LOG_TO_STDOUT:
        handlers.append(logging.StreamHandler())

    # setup root logger
    logging.basicConfig(
        format='[%(asctime)s] %(levelname)s: %(filename)s at %(lineno)d %(funcName)s(): %(message)s',
        level=logging.DEBUG if config.DEBUG else logging.INFO,
        handlers=handlers,
    )
